@@ -6,10 +6,11 @@ from celery.utils.log import get_task_logger
 from django.conf import settings
 
 from .models import *
+from .managers import BulkManager,chunks
 
 logger = get_task_logger(__name__)
 
-def chunks(d, n):
+def chunk_dict(d, n):
     allout = []
     temp = {}
     for k in d:
@@ -22,11 +23,11 @@ def chunks(d, n):
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(addLemmas.si(x) for x in chunks(list(lemmas),10000))
+    lemma_job = group(addLemmas.si(x) for x in chunk_dict(list(lemmas),10000))
     wfs,spells,trans = loadWF()
-    wf_job = group(addWFS.si(x) for x in chunks(wfs,10000))
-    spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
-    trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
+    wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
+    spell_job = group(addSpells.si(x) for x in chunk_dict(spells,10000))
+    trans_job = group(addTrans.si(x) for x in chunk_dict(trans,10000))
     res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
     res.get()
 
